summary refs log tree commit diff
path: root/build-aux
diff options
context:
space:
mode:
Diffstat (limited to 'build-aux')
-rw-r--r--build-aux/sync-descriptions.scm (renamed from build-aux/sync-synopses.scm)17
1 files changed, 15 insertions, 2 deletions
diff --git a/build-aux/sync-synopses.scm b/build-aux/sync-descriptions.scm
index c1049d3398..61362a1f88 100644
--- a/build-aux/sync-synopses.scm
+++ b/build-aux/sync-descriptions.scm
@@ -17,7 +17,8 @@
 ;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;;
 ;;; Report synopses that defer from those found in the GNU Womb.
 ;;;
 
 (use-modules (guix gnu-maintenance)
@@ -58,5 +59,17 @@
                 (format (guix-warning-port)
                         "~a: ~a: proposed synopsis: ~s~%"
                         (location->string loc) (package-name package)
-                        upstream)))))
+                        upstream)))
+
+            (let ((upstream   (gnu-package-doc-description descriptor))
+                  (downstream (package-description package))
+                  (loc        (or (package-field-location package 'description)
+                                  (package-location package))))
+              (when (and upstream
+                         (not (string=? (fill-paragraph upstream 100)
+                                        (fill-paragraph downstream 100))))
+                (format (guix-warning-port)
+                        "~a: ~a: proposed description:~%      ~a~%"
+                        (location->string loc) (package-name package)
+                        (fill-paragraph upstream 77 7))))))
           gnus)
@@ -17,7 +17,8 @@
 
 ;;;
-;;; Report synopses that defer from those found in the GNU Womb.
+;;; Report package synopses and descriptions that defer from those found in
+;;; the GNU Womb.
 ;;;
 